

=============
API Reference
=============

The pythreejs API attempts to mimic `the three.js API`_ as closely as possible.
This API reference therefore does not attempt to explain the purpose of any
forwarded objects or attributes, but can  still be useful for:

- The trait signatures of various properties.
- Classes, properties and methods custom to pythreejs.
- Variations from the three.js API, e.g. for :py:class:`~pythreejs.BufferAttribute`.

.. _`the three.js API`: https://threejs.org/docs/


.. automodule:: pythreejs
    :members:
    :undoc-members:


.. toctree::
    :maxdepth: 10

    ./_base/index
    ./animation/index
    ./audio/index
    ./cameras/index
    ./controls/index
    ./core/index
    ./extras/index
    ./geometries/index
    ./helpers/index
    ./lights/index
    ./loaders/index
    ./materials/index
    ./math/index
    ./objects/index
    ./renderers/index
    ./scenes/index
    ./textures/index
    ./traits.rst
